"""
This module provides a mapping of RhinoScriptSyntax functions to their categories.
Generated from the RhinoScriptSyntax documentation.
"""

def get_function_category(function_name):
    """
    Returns the category a RhinoScriptSyntax function belongs to.
    
    Args:
        function_name (str): The name of a RhinoScriptSyntax function
        
    Returns:
        str: The category name or None if function not found
    """
    if function_name in FUNCTION_CATEGORY_MAP:
        return FUNCTION_CATEGORY_MAP[function_name]
    return None

# Dictionary mapping function names to their categories
FUNCTION_CATEGORY_MAP = {
    # application
    "AddAlias": "application",
    "AddSearchPath": "application",
    "AliasCount": "application",
    "AliasMacro": "application",
    "AliasNames": "application",
    "AppearanceColor": "application",
    "AutosaveFile": "application",
    "AutosaveInterval": "application",
    "BuildDate": "application",
    "ClearCommandHistory": "application",
    "Command": "application",
    "CommandHistory": "application",
    "DefaultRenderer": "application",
    "DeleteAlias": "application",
    "DeleteSearchPath": "application",
    "DisplayOleAlerts": "application",
    "EdgeAnalysisColor": "application",
    "EdgeAnalysisMode": "application",
    "EnableAutosave": "application",
    "EnablePlugIn": "application",
    "ExeFolder": "application",
    "ExePlatform": "application",
    "ExeServiceRelease": "application",
    "ExeVersion": "application",
    "Exit": "application",
    "FindFile": "application",
    "GetPlugInObject": "application",
    "InCommand": "application",
    "InstallFolder": "application",
    "IsAlias": "application",
    "IsCommand": "application",
    "IsPlugIn": "application",
    "IsRunningOnWindows": "application",
    "LastCommandName": "application",
    "LastCommandResult": "application",
    "LocaleID": "application",
    "Ortho": "application",
    "Osnap": "application",
    "OsnapDialog": "application",
    "OsnapMode": "application",
    "Planar": "application",
    "PlugInId": "application",
    "PlugIns": "application",
    "ProjectOsnaps": "application",
    "Prompt": "application",
    "ScreenSize": "application",
    "SdkVersion": "application",
    "SearchPathCount": "application",
    "SearchPathList": "application",
    "SendKeystrokes": "application",
    "Snap": "application",
    "StatusBarDistance": "application",
    "StatusBarMessage": "application",
    "StatusBarPoint": "application",
    "StatusBarProgressMeterShow": "application",
    "StatusBarProgressMeterUpdate": "application",
    "StatusBarProgressMeterHide": "application",
    "TemplateFile": "application",
    "TemplateFolder": "application",
    "WindowHandle": "application",
    "WorkingFolder": "application",
    
    # block
    "AddBlock": "block",
    "BlockContainerCount": "block",
    "BlockContainers": "block",
    "BlockCount": "block",
    "BlockDescription": "block",
    "BlockInstanceCount": "block",
    "BlockInstanceInsertPoint": "block",
    "BlockInstanceName": "block",
    "BlockInstances": "block",
    "BlockInstanceXform": "block",
    "BlockNames": "block",
    "BlockObjectCount": "block",
    "BlockObjects": "block",
    "BlockPath": "block",
    "BlockStatus": "block",
    "DeleteBlock": "block",
    "ExplodeBlockInstance": "block",
    "InsertBlock": "block",
    "InsertBlock2": "block",
    "IsBlock": "block",
    "IsBlockEmbedded": "block",
    "IsBlockInstance": "block",
    "IsBlockInUse": "block",
    "IsBlockReference": "block",
    "RenameBlock": "block",

    # curve
    "AddArc": "curve",
    "AddArc3Pt": "curve",
    "AddArcPtTanPt": "curve",
    "AddBlendCurve": "curve",
    "AddCircle": "curve",
    "AddCircle3Pt": "curve",
    "AddCurve": "curve",
    "AddEllipse": "curve",
    "AddEllipse3Pt": "curve",
    "AddFilletCurve": "curve",
    "AddInterpCrvOnSrf": "curve",
    "AddInterpCrvOnSrfUV": "curve",
    "AddInterpCurve": "curve",
    "AddLine": "curve",
    "AddNurbsCurve": "curve",
    "AddPolyline": "curve",
    "AddRectangle": "curve",
    "AddSpiral": "curve",
    "AddSubCrv": "curve",
    "ArcAngle": "curve",
    "ArcCenterPoint": "curve",
    "ArcMidPoint": "curve",
    "ArcRadius": "curve",
    "CircleCenterPoint": "curve",
    "CircleCircumference": "curve",
    "CircleRadius": "curve",
    "CloseCurve": "curve",
    "ClosedCurveOrientation": "curve",
    "ConvertCurveToPolyline": "curve",
    "CurveArcLengthPoint": "curve",
    "CurveArea": "curve",
    "CurveAreaCentroid": "curve",
    "CurveArrows": "curve",
    "CurveBooleanDifference": "curve",
    "CurveBooleanIntersection": "curve",
    "CurveBooleanUnion": "curve",
    "CurveBrepIntersect": "curve",
    "CurveClosestObject": "curve",
    "CurveClosestPoint": "curve",
    "CurveContourPoints": "curve",
    "CurveCurvature": "curve",
    "CurveCurveIntersection": "curve",
    "CurveDegree": "curve",
    "CurveDeviation": "curve",
    "CurveDim": "curve",
    "CurveDirectionsMatch": "curve",
    "CurveDiscontinuity": "curve",
    "CurveDomain": "curve",
    "CurveEditPoints": "curve",
    "CurveEndPoint": "curve",
    "CurveFilletPoints": "curve",
    "CurveFrame": "curve",
    "CurveKnotCount": "curve",
    "CurveKnots": "curve",
    "CurveLength": "curve",
    "CurveMidPoint": "curve",
    "CurveNormal": "curve",
    "CurveNormalizedParameter": "curve",
    "CurveParameter": "curve",
    "CurvePerpFrame": "curve",
    "CurvePlane": "curve",
    "CurvePointCount": "curve",
    "CurvePoints": "curve",
    "CurveRadius": "curve",
    "CurveSeam": "curve",
    "CurveStartPoint": "curve",
    "CurveSurfaceIntersection": "curve",
    "CurveTangent": "curve",
    "CurveWeights": "curve",
    "DivideCurve": "curve",
    "DivideCurveEquidistant": "curve",
    "DivideCurveLength": "curve",
    "EllipseCenterPoint": "curve",
    "EllipseQuadPoints": "curve",
    "EvaluateCurve": "curve",
    "ExplodeCurves": "curve",
    "ExtendCurve": "curve",
    "ExtendCurveLength": "curve",
    "ExtendCurvePoint": "curve",
    "FairCurve": "curve",
    "FitCurve": "curve",
    "InsertCurveKnot": "curve",
    "IsArc": "curve",
    "IsCircle": "curve",
    "IsCurve": "curve",
    "IsCurveClosable": "curve",
    "IsCurveClosed": "curve",
    "IsCurveInPlane": "curve",
    "IsCurveLinear": "curve",
    "IsCurvePeriodic": "curve",
    "IsCurvePlanar": "curve",
    "IsCurveRational": "curve",
    "IsEllipse": "curve",
    "IsLine": "curve",
    "IsPointOnCurve": "curve",
    "IsPolyCurve": "curve",
    "IsPolyline": "curve",
    "JoinCurves": "curve",
    "LineFitFromPoints": "curve",
    "MakeCurveNonPeriodic": "curve",
    "MeanCurve": "curve",
    "MeshPolyline": "curve",
    "OffsetCurve": "curve",
    "OffsetCurveOnSurface": "curve",
    "PlanarClosedCurveContainment": "curve",
    "PlanarCurveCollision": "curve",
    "PointInPlanarClosedCurve": "curve",
    "PolyCurveCount": "curve",
    "PolylineVertices": "curve",
    "ProjectCurveToMesh": "curve",
    "ProjectCurveToSurface": "curve",
    "RebuildCurve": "curve",
    "RemoveCurveKnot": "curve",
    "ReverseCurve": "curve",
    "SimplifyCurve": "curve",
    "SplitCurve": "curve",
    "TrimCurve": "curve",
    "ChangeCurveDegree": "curve",
    "AddTweenCurves": "curve",
    
    # dimension
    "AddAlignedDimension": "dimension",
    "AddDimStyle": "dimension",
    "AddLeader": "dimension",
    "AddLinearDimension": "dimension",
    "CurrentDimStyle": "dimension",
    "DeleteDimStyle": "dimension",
    "DimensionStyle": "dimension",
    "DimensionText": "dimension",
    "DimensionUserText": "dimension",
    "DimensionValue": "dimension",
    "DimStyleAnglePrecision": "dimension",
    "DimStyleArrowSize": "dimension",
    "DimStyleCount": "dimension",
    "DimStyleExtension": "dimension",
    "DimStyleFont": "dimension",
    "DimStyleLeaderArrowSize": "dimension",
    "DimStyleLengthFactor": "dimension",
    "DimStyleLinearPrecision": "dimension",
    "DimStyleNames": "dimension",
    "DimStyleNumberFormat": "dimension",
    "DimStyleOffset": "dimension",
    "DimStylePrefix": "dimension",
    "DimStyleScale": "dimension",
    "DimStyleSuffix": "dimension",
    "DimStyleTextAlignment": "dimension",
    "DimStyleTextGap": "dimension",
    "DimStyleTextHeight": "dimension",
    "IsAlignedDimension": "dimension",
    "IsAngularDimension": "dimension",
    "IsDiameterDimension": "dimension",
    "IsDimension": "dimension",
    "IsDimStyle": "dimension",
    "IsDimStyleReference": "dimension",
    "IsLeader": "dimension",
    "IsLinearDimension": "dimension",
    "IsOrdinateDimension": "dimension",
    "IsRadialDimension": "dimension",
    "LeaderText": "dimension",
    "RenameDimStyle": "dimension",
    
    # document
    "CreatePreviewImage": "document",
    "DocumentModified": "document",
    "DocumentName": "document",
    "DocumentPath": "document",
    "EnableRedraw": "document",
    "ExtractPreviewImage": "document",
    "IsDocumentModified": "document",
    "Notes": "document",
    "ReadFileVersion": "document",
    "Redraw": "document",
    "RenderAntialias": "document",
    "RenderColor": "document",
    "RenderResolution": "document",
    "RenderMeshDensity": "document",
    "RenderMeshMaxAngle": "document",
    "RenderMeshMaxAspectRatio": "document",
    "RenderMeshMaxDistEdgeToSrf": "document",
    "RenderMeshMaxEdgeLength": "document",
    "RenderMeshMinEdgeLength": "document",
    "RenderMeshMinInitialGridQuads": "document",
    "RenderMeshQuality": "document",
    "RenderMeshSettings": "document",
    "RenderSettings": "document",
    "UnitAbsoluteTolerance": "document",
    "UnitAngleTolerance": "document",
    "UnitDistanceDisplayPrecision": "document",
    "UnitRelativeTolerance": "document",
    "UnitScale": "document",
    "UnitSystem": "document",
    "UnitSystemName": "document",
    
    # geometry
    "AddClippingPlane": "geometry",
    "AddPictureFrame": "geometry",
    "AddPoint": "geometry",
    "AddPointCloud": "geometry",
    "AddPoints": "geometry",
    "AddText": "geometry",
    "AddTextDot": "geometry",
    "Area": "geometry",
    "BoundingBox": "geometry",
    "CompareGeometry": "geometry",
    "ExplodeText": "geometry",
    "IsClippingPlane": "geometry",
    "IsPoint": "geometry",
    "IsPointCloud": "geometry",
    "IsText": "geometry",
    "IsTextDot": "geometry",
    "PointCloudCount": "geometry",
    "PointCloudHasHiddenPoints": "geometry",
    "PointCloudHasPointColors": "geometry",
    "PointCloudHidePoints": "geometry",
    "PointCloudPointColors": "geometry",
    "PointCloudPoints": "geometry",
    "PointCloudKNeighbors": "geometry",
    "PointCloudClosestPoints": "geometry",
    "PointCoordinates": "geometry",
    "TextDotFont": "geometry",
    "TextDotHeight": "geometry",
    "TextDotPoint": "geometry",
    "TextDotText": "geometry",
    "TextObjectFont": "geometry",
    "TextObjectHeight": "geometry",
    "TextObjectPlane": "geometry",
    "TextObjectPoint": "geometry",
    "TextObjectStyle": "geometry",
    "TextObjectText": "geometry",
    
    # grips
    "EnableObjectGrips": "grips",
    "GetObjectGrip": "grips",
    "GetObjectGrips": "grips",
    "NextObjectGrip": "grips",
    "ObjectGripCount": "grips",
    "ObjectGripLocation": "grips",
    "ObjectGripLocations": "grips",
    "ObjectGripsOn": "grips",
    "ObjectGripsSelected": "grips",
    "PrevObjectGrip": "grips",
    "SelectedObjectGrips": "grips",
    "SelectObjectGrip": "grips",
    "SelectObjectGrips": "grips",
    "UnselectObjectGrip": "grips",
    "UnselectObjectGrips": "grips",
    
    # group
    "AddGroup": "group",
    "AddObjectsToGroup": "group",
    "AddObjectToGroup": "group",
    "DeleteGroup": "group",
    "GroupCount": "group",
    "GroupNames": "group",
    "HideGroup": "group",
    "IsGroup": "group",
    "IsGroupEmpty": "group",
    "LockGroup": "group",
    "RemoveObjectFromAllGroups": "group",
    "RemoveObjectFromGroup": "group",
    "RemoveObjectsFromGroup": "group",
    "RenameGroup": "group",
    "ShowGroup": "group",
    "UnlockGroup": "group",
    "ObjectTopGroup": "group",
    
    # hatch
    "AddHatch": "hatch",
    "AddHatches": "hatch",
    "AddHatchPatterns": "hatch",
    "CurrentHatchPattern": "hatch",
    "ExplodeHatch": "hatch",
    "HatchPattern": "hatch",
    "HatchPatternCount": "hatch",
    "HatchPatternDescription": "hatch",
    "HatchPatternFillType": "hatch",
    "HatchPatternNames": "hatch",
    "HatchRotation": "hatch",
    "HatchScale": "hatch",
    "IsHatch": "hatch",
    "IsHatchPattern": "hatch",
    "IsHatchPatternCurrent": "hatch",
    "IsHatchPatternReference": "hatch",
    
    # layer
    "AddLayer": "layer",
    "CurrentLayer": "layer",
    "DeleteLayer": "layer",
    "ExpandLayer": "layer",
    "IsLayer": "layer",
    "IsLayerChangeable": "layer",
    "IsLayerChildOf": "layer",
    "IsLayerCurrent": "layer",
    "IsLayerEmpty": "layer",
    "IsLayerExpanded": "layer",
    "IsLayerLocked": "layer",
    "IsLayerOn": "layer",
    "IsLayerSelectable": "layer",
    "IsLayerParentOf": "layer",
    "IsLayerReference": "layer",
    "IsLayerVisible": "layer",
    "LayerChildCount": "layer",
    "LayerChildren": "layer",
    "LayerColor": "layer",
    "LayerCount": "layer",
    "LayerIds": "layer",
    "LayerLinetype": "layer",
    "LayerLocked": "layer",
    "LayerMaterialIndex": "layer",
    "LayerId": "layer",
    "LayerName": "layer",
    "LayerNames": "layer",
    "LayerOrder": "layer",
    "LayerPrintColor": "layer",
    "LayerPrintWidth": "layer",
    "LayerVisible": "layer",
    "ParentLayer": "layer",
    "PurgeLayer": "layer",
    "RenameLayer": "layer",
    
    # light
    "AddDirectionalLight": "light",
    "AddLinearLight": "light",
    "AddPointLight": "light",
    "AddRectangularLight": "light",
    "AddSpotLight": "light",
    "EnableLight": "light",
    "IsDirectionalLight": "light",
    "IsLight": "light",
    "IsLightEnabled": "light",
    "IsLightReference": "light",
    "IsLinearLight": "light",
    "IsPointLight": "light",
    "IsRectangularLight": "light",
    "IsSpotLight": "light",
    "LightColor": "light",
    "LightCount": "light",
    "LightDirection": "light",
    "LightLocation": "light",
    "LightName": "light",
    "LightObjects": "light",
    "RectangularLightPlane": "light",
    "SpotLightHardness": "light",
    "SpotLightRadius": "light",
    "SpotLightShadowIntensity": "light",
    
    # line
    "LineClosestPoint": "line",
    "LineCylinderIntersection": "line",
    "LineIsFartherThan": "line",
    "LineLineIntersection": "line",
    "LineMaxDistanceTo": "line",
    "LineMinDistanceTo": "line",
    "LinePlane": "line",
    "LinePlaneIntersection": "line",
    "LineSphereIntersection": "line",
    "LineTransform": "line",
    
    # linetype
    "IsLinetype": "linetype",
    "IsLinetypeReference": "linetype",
    "LinetypeCount": "linetype",
    "LinetypeNames": "linetype",
    
    # material
    "AddMaterialToLayer": "material",
    "AddMaterialToObject": "material",
    "CopyMaterial": "material",
    "IsMaterialDefault": "material",
    "IsMaterialReference": "material",
    "MatchMaterial": "material",
    "MaterialBump": "material",
    "MaterialColor": "material",
    "MaterialEnvironmentMap": "material",
    "MaterialName": "material",
    "MaterialReflectiveColor": "material",
    "MaterialShine": "material",
    "MaterialTexture": "material",
    "MaterialTransparency": "material",
    "MaterialTransparencyMap": "material",
    "ResetMaterial": "material",
    
    # mesh
    "AddMesh": "mesh",
    "AddPlanarMesh": "mesh",
    "CurveMeshIntersection": "mesh",
    "DisjointMeshCount": "mesh",
    "DuplicateMeshBorder": "mesh",
    "ExplodeMeshes": "mesh",
    "IsMesh": "mesh",
    "IsMeshClosed": "mesh",
    "IsMeshManifold": "mesh",
    "IsPointOnMesh": "mesh",
    "JoinMeshes": "mesh",
    "MeshArea": "mesh",
    "MeshAreaCentroid": "mesh",
    "MeshBooleanDifference": "mesh",
    "MeshBooleanIntersection": "mesh",
    "MeshBooleanSplit": "mesh",
    "MeshBooleanUnion": "mesh",
    "MeshClosestPoint": "mesh",
    "MeshFaceCenters": "mesh",
    "MeshFaceCount": "mesh",
    "MeshFaceNormals": "mesh",
    "MeshFaces": "mesh",
    "MeshFaceVertices": "mesh",
    "MeshHasFaceNormals": "mesh",
    "MeshHasTextureCoordinates": "mesh",
    "MeshHasVertexColors": "mesh",
    "MeshHasVertexNormals": "mesh",
    "MeshMeshIntersection": "mesh",
    "MeshNakedEdgePoints": "mesh",
    "MeshOffset": "mesh",
    "MeshOutline": "mesh",
    "MeshQuadCount": "mesh",
    "MeshQuadsToTriangles": "mesh",
    "MeshToNurb": "mesh",
    "MeshTriangleCount": "mesh",
    "MeshVertexColors": "mesh",
    "MeshVertexCount": "mesh",
    "MeshVertexFaces": "mesh",
    "MeshVertexNormals": "mesh",
    "MeshVertices": "mesh",
    "MeshVolume": "mesh",
    "MeshVolumeCentroid": "mesh",
    "PullCurveToMesh": "mesh",
    "SplitDisjointMesh": "mesh",
    "UnifyMeshNormals": "mesh",
    
    # object
    "CopyObject": "object",
    "CopyObjects": "object",
    "DeleteObject": "object",
    "DeleteObjects": "object",
    "FlashObject": "object",
    "HideObject": "object",
    "HideObjects": "object",
    "IsLayoutObject": "object",
    "IsObject": "object",
    "IsObjectHidden": "object",
    "IsObjectInBox": "object",
    "IsObjectInGroup": "object",
    "IsObjectLocked": "object",
    "IsObjectNormal": "object",
    "IsObjectReference": "object",
    "IsObjectSelectable": "object",
    "IsObjectSelected": "object",
    "IsObjectSolid": "object",
    "IsObjectValid": "object",
    "IsVisibleInView": "object",
    "LockObject": "object",
    "LockObjects": "object",
    "MatchObjectAttributes": "object",
    "MirrorObject": "object",
    "MirrorObjects": "object",
    "MoveObject": "object",
    "MoveObjects": "object",
    "ObjectColor": "object",
    "ObjectColorSource": "object",
    "ObjectDescription": "object",
    "ObjectGroups": "object",
    "ObjectLayer": "object",
    "ObjectLayout": "object",
    "ObjectLinetype": "object",
    "ObjectLinetypeSource": "object",
    "ObjectMaterialIndex": "object",
    "ObjectMaterialSource": "object",
    "ObjectName": "object",
    "ObjectPrintColor": "object",
    "ObjectPrintColorSource": "object",
    "ObjectPrintWidth": "object",
    "ObjectPrintWidthSource": "object",
    "ObjectType": "object",
    "OrientObject": "object",
    "RotateObject": "object",
    "RotateObjects": "object",
    "ScaleObject": "object",
    "ScaleObjects": "object",
    "SelectObject": "object",
    "SelectObjects": "object",
    "ShearObject": "object",
    "ShearObjects": "object",
    "ShowObject": "object",
    "ShowObjects": "object",
    "TransformObject": "object",
    "TransformObjects": "object",
    "UnlockObject": "object",
    "UnlockObjects": "object",
    "UnselectObject": "object",
    "UnselectObjects": "object",
    
    # plane
    "DistanceToPlane": "plane",
    "EvaluatePlane": "plane",
    "IntersectPlanes": "plane",
    "MovePlane": "plane",
    "PlaneClosestPoint": "plane",
    "PlaneCurveIntersection": "plane",
    "PlaneEquation": "plane",
    "PlaneFitFromPoints": "plane",
    "PlaneFromFrame": "plane",
    "PlaneFromNormal": "plane",
    "PlaneFromPoints": "plane",
    "PlanePlaneIntersection": "plane",
    "PlaneSphereIntersection": "plane",
    "PlaneTransform": "plane",
    "RotatePlane": "plane",
    "WorldXYPlane": "plane",
    "WorldYZPlane": "plane",
    "WorldZXPlane": "plane",
    
    # pointvector
    "IsVectorParallelTo": "pointvector",
    "IsVectorPerpendicularTo": "pointvector",
    "IsVectorTiny": "pointvector",
    "IsVectorZero": "pointvector",
    "PointAdd": "pointvector",
    "PointArrayClosestPoint": "pointvector",
    "PointArrayTransform": "pointvector",
    "PointClosestObject": "pointvector",
    "PointCompare": "pointvector",
    "PointDivide": "pointvector",
    "PointsAreCoplanar": "pointvector",
    "PointScale": "pointvector",
    "PointSubtract": "pointvector",
    "PointTransform": "pointvector",
    "ProjectPointToMesh": "pointvector",
    "ProjectPointToSurface": "pointvector",
    "PullPoints": "pointvector",
    "VectorAdd": "pointvector",
    "VectorAngle": "pointvector",
    "VectorCompare": "pointvector",
    "VectorCreate": "pointvector",
    "VectorCrossProduct": "pointvector",
    "VectorDivide": "pointvector",
    "VectorDotProduct": "pointvector",
    "VectorLength": "pointvector",
    "VectorMultiply": "pointvector",
    "VectorReverse": "pointvector",
    "VectorRotate": "pointvector",
    "VectorScale": "pointvector",
    "VectorSubtract": "pointvector",
    "VectorTransform": "pointvector",
    "VectorUnitize": "pointvector",
    "PointArrayBoundingBox": "pointvector",
    
    # selection
    "AllObjects": "selection",
    "FirstObject": "selection",
    "GetCurveObject": "selection",
    "GetObject": "selection",
    "GetObjectEx": "selection",
    "GetObjects": "selection",
    "GetObjectsEx": "selection",
    "GetPointCoordinates": "selection",
    "GetSurfaceObject": "selection",
    "LockedObjects": "selection",
    "HiddenObjects": "selection",
    "InvertSelectedObjects": "selection",
    "LastCreatedObjects": "selection",
    "LastObject": "selection",
    "NextObject": "selection",
    "NormalObjects": "selection",
    "ObjectsByColor": "selection",
    "ObjectsByGroup": "selection",
    "ObjectsByLayer": "selection",
    "ObjectsByName": "selection",
    "ObjectsByType": "selection",
    "SelectedObjects": "selection",
    "UnselectAllObjects": "selection",
    "VisibleObjects": "selection",
    "WindowPick": "selection",
    
    # surface
    "AddBox": "surface",
    "AddCone": "surface",
    "AddCutPlane": "surface",
    "AddCylinder": "surface",
    "AddEdgeSrf": "surface",
    "AddNetworkSrf": "surface",
    "AddNurbsSurface": "surface",
    "AddPatch": "surface",
    "AddPipe": "surface",
    "AddPlanarSrf": "surface",
    "AddPlaneSurface": "surface",
    "AddLoftSrf": "surface",
    "AddRevSrf": "surface",
    "AddSphere": "surface",
    "AddSrfContourCrvs": "surface",
    "AddSrfControlPtGrid": "surface",
    "AddSrfPt": "surface",
    "AddSrfPtGrid": "surface",
    "AddSweep1": "surface",
    "AddSweep2": "surface",
    "AddRailRevSrf": "surface",
    "AddTorus": "surface",
    "BooleanDifference": "surface",
    "BooleanIntersection": "surface",
    "BooleanUnion": "surface",
    "BrepClosestPoint": "surface",
    "CapPlanarHoles": "surface",
    "DuplicateEdgeCurves": "surface",
    "DuplicateSurfaceBorder": "surface",
    "EvaluateSurface": "surface",
    "ExtendSurface": "surface",
    "ExplodePolysurfaces": "surface",
    "ExtractIsoCurve": "surface",
    "ExtractSurface": "surface",
    "ExtrudeCurve": "surface",
    "ExtrudeCurvePoint": "surface",
    "ExtrudeCurveStraight": "surface",
    "ExtrudeSurface": "surface",
    "FilletSurfaces": "surface",
    "FlipSurface": "surface",
    "IntersectBreps": "surface",
    "IntersectSpheres": "surface",
    "IsBrep": "surface",
    "IsCone": "surface",
    "IsCylinder": "surface",
    "IsPlaneSurface": "surface",
    "IsPointInSurface": "surface",
    "IsPointOnSurface": "surface",
    "IsPolysurface": "surface",
    "IsPolysurfaceClosed": "surface",
    "IsSphere": "surface",
    "IsSurface": "surface",
    "IsSurfaceClosed": "surface",
    "IsSurfacePeriodic": "surface",
    "IsSurfacePlanar": "surface",
    "IsSurfaceRational": "surface",
    "IsSurfaceSingular": "surface",
    "IsSurfaceTrimmed": "surface",
    "IsTorus": "surface",
    "SurfaceSphere": "surface",
    "JoinSurfaces": "surface",
    "MakeSurfacePeriodic": "surface",
    "OffsetSurface": "surface",
    "PullCurve": "surface",
    "RebuildSurface": "surface",
    "RemoveSurfaceKnot": "surface",
    "ReverseSurface": "surface",
    "ShootRay": "surface",
    "ShortPath": "surface",
    "ShrinkTrimmedSurface": "surface",
    "SplitBrep": "surface",
    "SurfaceArea": "surface",
    "SurfaceAreaCentroid": "surface",
    "SurfaceAreaMoments": "surface",
    "SurfaceClosestPoint": "surface",
    "SurfaceCone": "surface",
    "SurfaceCurvature": "surface",
    "SurfaceCylinder": "surface",
    "SurfaceDegree": "surface",
    "SurfaceDomain": "surface",
    "SurfaceEditPoints": "surface",
    "SurfaceEvaluate": "surface",
    "SurfaceFrame": "surface",
    "SurfaceIsocurveDensity": "surface",
    "SurfaceKnotCount": "surface",
    "SurfaceKnots": "surface",
    "SurfaceNormal": "surface",
    "SurfaceNormalizedParameter": "surface",
    "SurfaceParameter": "surface",
    "SurfacePointCount": "surface",
    "SurfacePoints": "surface",
    "SurfaceTorus": "surface",
    "SurfaceVolume": "surface",
    "SurfaceVolumeCentroid": "surface",
    "SurfaceVolumeMoments": "surface",
    "SurfaceWeights": "surface",
    "TrimBrep": "surface",
    "TrimSurface": "surface",
    "UnrollSurface": "surface",
    "ChangeSurfaceDegree": "surface",
    
    # toolbar
    "CloseToolbarCollection": "toolbar",
    "HideToolbar": "toolbar",
    "IsToolbar": "toolbar",
    "IsToolbarCollection": "toolbar",
    "IsToolbarDocked": "toolbar",
    "IsToolbarVisible": "toolbar",
    "OpenToolbarCollection": "toolbar",
    "SaveToolbarCollection": "toolbar",
    "SaveToolbarCollectionAs": "toolbar",
    "ShowToolbar": "toolbar",
    "ToolbarCollectionCount": "toolbar",
    "ToolbarCollectionNames": "toolbar",
    "ToolbarCollectionPath": "toolbar",
    "ToolbarCount": "toolbar",
    "ToolbarNames": "toolbar",
    
    # transformation
    "IsXformIdentity": "transformation",
    "IsXformSimilarity": "transformation",
    "IsXformZero": "transformation",
    "XformChangeBasis": "transformation",
    "XformChangeBasis2": "transformation",
    "XformCompare": "transformation",
    "XformCPlaneToWorld": "transformation",
    "XformDeterminant": "transformation",
    "XformDiagonal": "transformation",
    "XformIdentity": "transformation",
    "XformInverse": "transformation",
    "XformMirror": "transformation",
    "XformMultiply": "transformation",
    "XformPlanarProjection": "transformation",
    "XformRotation1": "transformation",
    "XformRotation2": "transformation",
    "XformRotation3": "transformation",
    "XformRotation4": "transformation",
    "XformScale": "transformation",
    "XformScreenToWorld": "transformation",
    "XformShear": "transformation",
    "XformTranslation": "transformation",
    "XformWorldToCPlane": "transformation",
    "XformWorldToScreen": "transformation",
    "XformZero": "transformation",
    
    # userdata
    "DeleteDocumentData": "userdata",
    "DocumentDataCount": "userdata",
    "DocumentUserTextCount": "userdata",
    "GetDocumentData": "userdata",
    "GetDocumentUserText": "userdata",
    "GetUserText": "userdata",
    "IsDocumentData": "userdata",
    "IsDocumentUserText": "userdata",
    "IsUserText": "userdata",
    "SetDocumentData": "userdata",
    "SetDocumentUserText": "userdata",
    "SetUserText": "userdata",
    
    # userinterface
    "BrowseForFolder": "userinterface",
    "CheckListBox": "userinterface",
    "ComboListBox": "userinterface",
    "EditBox": "userinterface",
    "GetAngle": "userinterface",
    "GetBoolean": "userinterface",
    "GetBox": "userinterface",
    "GetColor": "userinterface",
    "GetCursorPos": "userinterface",
    "GetDistance": "userinterface",
    "GetEdgeCurves": "userinterface",
    "GetInteger": "userinterface",
    "GetLayer": "userinterface",
    "GetLayers": "userinterface",
    "GetLine": "userinterface",
    "GetLinetype": "userinterface",
    "GetMeshFaces": "userinterface",
    "GetMeshVertices": "userinterface",
    "GetPoint": "userinterface",
    "GetPointOnCurve": "userinterface",
    "GetPointOnMesh": "userinterface",
    "GetPointOnSurface": "userinterface",
    "GetPoints": "userinterface",
    "GetPolyline": "userinterface",
    "GetReal": "userinterface",
    "GetRectangle": "userinterface",
    "GetString": "userinterface",
    "ListBox": "userinterface",
    "MessageBox": "userinterface",
    "PropertyListBox": "userinterface",
    "MultiListBox": "userinterface",
    "OpenFileName": "userinterface",
    "OpenFileNames": "userinterface",
    "PopupMenu": "userinterface",
    "RealBox": "userinterface",
    "SaveFileName": "userinterface",
    "StringBox": "userinterface",
    "TextOut": "userinterface",
    
    # utility
    "ContextIsRhino": "utility",
    "ContextIsGrasshopper": "utility",
    "Angle": "utility",
    "Angle2": "utility",
    "ClipboardText": "utility",
    "ColorAdjustLuma": "utility",
    "ColorBlueValue": "utility",
    "ColorGreenValue": "utility",
    "ColorHLSToRGB": "utility",
    "ColorRedValue": "utility",
    "ColorRGBToHLS": "utility",
    "CullDuplicateNumbers": "utility",
    "CullDuplicatePoints": "utility",
    "Distance": "utility",
    "GetSettings": "utility",
    "Polar": "utility",
    "SimplifyArray": "utility",
    "Sleep": "utility",
    "SortPointList": "utility",
    "SortPoints": "utility",
    "Str2Pt": "utility",
    "CreatePoint": "utility",
    "CreateVector": "utility",
    "CreatePlane": "utility",
    "CreateXform": "utility",
    "CreateColor": "utility",
    "CreateInterval": "utility",
    
    # view
    "AddDetail": "view",
    "AddLayout": "view",
    "AddNamedCPlane": "view",
    "AddNamedView": "view",
    "CurrentDetail": "view",
    "CurrentView": "view",
    "DeleteNamedCPlane": "view",
    "DeleteNamedView": "view",
    "DetailLock": "view",
    "DetailScale": "view",
    "IsDetail": "view",
    "IsLayout": "view",
    "IsView": "view",
    "IsViewCurrent": "view",
    "IsViewMaximized": "view",
    "IsViewPerspective": "view",
    "IsViewTitleVisible": "view",
    "IsWallpaper": "view",
    "MaximizeRestoreView": "view",
    "NamedCPlane": "view",
    "NamedCPlanes": "view",
    "NamedViews": "view",
    "RenameView": "view",
    "RestoreNamedCPlane": "view",
    "RestoreNamedView": "view",
    "RotateCamera": "view",
    "RotateView": "view",
    "ShowGrid": "view",
    "ShowGridAxes": "view",
    "ShowViewTitle": "view",
    "ShowWorldAxes": "view",
    "TiltView": "view",
    "ViewCamera": "view",
    "ViewCameraLens": "view",
    "ViewCameraPlane": "view",
    "ViewCameraTarget": "view",
    "ViewCameraUp": "view",
    "ViewCPlane": "view",
    "ViewDisplayMode": "view",
    "ViewDisplayModeId": "view",
    "ViewDisplayModeName": "view",
    "ViewDisplayModes": "view",
    "ViewNames": "view",
    "ViewNearCorners": "view",
    "ViewProjection": "view",
    "ViewRadius": "view",
    "ViewSize": "view",
    "ViewSpeedTest": "view",
    "ViewTarget": "view",
    "ViewTitle": "view",
    "Wallpaper": "view",
    "WallpaperGrayScale": "view",
    "WallpaperHidden": "view",
    "ZoomBoundingBox": "view",
    "ZoomExtents": "view",
    "ZoomSelected": "view",
}
